==> dart_std-0.0.5.tar.gz: lib/dart_std.dart <==
/*
 * *
 *  * * GNU General Public License v3.0
 *  * *******************************************************************************************
 *  *  *  Created By Debojyoti Singha
 *  *  *  Copyright (c) 2023.
 *  *  * This program is free software: you can redistribute it and/or modify
 *  *  * it under the terms of the GNU General Public License as published by
 *  *  * the Free Software Foundation, either version 3 of the License, or
 *  *  * (at your option) any later version.
 *  *  *
 *  *  * This program is distributed in the hope that it will be useful,
 *  *  *
 *  *  * but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  *  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  *  * GNU General Public License for more details.
 *  *  *
 *  *  * You should have received a copy of the GNU General Public License
 *  *  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *  *  * Contact Email: support@swingtechnologies.in
 *  * ******************************************************************************************
 *
 */

library dart_std;

import 'dart:ui';

import 'package:characters/characters.dart' as chr;
import 'package:collection/collection.dart' as std;
import 'package:dart_std/src/utils/utils.dart';

part 'src/ext/int_ext.dart';
part 'src/ext/list_ext.dart';
part 'src/ext/map_ext.dart';
part 'src/ext/sorted_list.dart';
part 'src/ext/string_ext.dart';
part 'src/utils/pair.dart';
part 'src/utils/triple.dart';
part 'src/data_types/dynamic_number.dart';

==> dart_std-0.0.6.tar.gz: lib/dart_std.dart <==
/*
 * *
 *  * * GNU General Public License v3.0
 *  * *******************************************************************************************
 *  *  *  Created By Debojyoti Singha
 *  *  *  Copyright (c) 2023.
 *  *  * This program is free software: you can redistribute it and/or modify
 *  *  * it under the terms of the GNU General Public License as published by
 *  *  * the Free Software Foundation, either version 3 of the License, or
 *  *  * (at your option) any later version.
 *  *  *
 *  *  * This program is distributed in the hope that it will be useful,
 *  *  *
 *  *  * but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  *  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  *  * GNU General Public License for more details.
 *  *  *
 *  *  * You should have received a copy of the GNU General Public License
 *  *  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *  *  * Contact Email: support@swingtechnologies.in
 *  * ******************************************************************************************
 *
 */

library dart_std;


import 'package:characters/characters.dart' as chr;
import 'package:collection/collection.dart' as std;
import 'src/utils/utils.dart';
import 'package:flutter/material.dart';

part 'src/ext/int_ext.dart';
part 'src/ext/list_ext.dart';
part 'src/ext/map_ext.dart';
part 'src/ext/sorted_list.dart';
part 'src/ext/string_ext.dart';
part 'src/utils/pair.dart';
part 'src/utils/triple.dart';
part 'src/data_types/dynamic_number.dart';
part 'src/ext/context_ext.dart';
